==> rivendell-1.6.0.tar.gz: rivendell-1.6.0/utils/rdgpimon/rdgpimon_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>Database Error</source>
        <translation>Datenbankfehler</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <comment>Unable to connect to mySQL Server!</comment>
        <translation>Kann keine Verbindung zum mySQL-Server herstellen</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Kann keine Verbindung herstellen</translation>
    </message>
    <message>
        <source>Unable to connect to mySQL Server!</source>
        <translation>Kann keine Verbindung zum mySQL-Server herstellen!</translation>
    </message>
    <message>
        <source>Matrix:</source>
        <translation>Matrix:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>S&amp;chließen</translation>
    </message>
    <message>
        <source>RDGpiMon - User:</source>
        <translation>RDGpiMon-Benutzer:</translation>
    </message>
    <message>
        <source>Show:</source>
        <translation>Zeigen:</translation>
    </message>
    <message>
        <source>GPI (Inputs)</source>
        <translation>GPI (Eingänge)</translation>
    </message>
    <message>
        <source>GPO (Outputs)</source>
        <translation>GPO (Ausgänge)</translation>
    </message>
    <message>
        <source>Green = ON Cart</source>
        <translation>Grün = ON Cart</translation>
    </message>
    <message>
        <source>Red = OFF Cart</source>
        <translation>Rot = OFF Cart</translation>
    </message>
</context>
</TS>

==> rivendell-2.15.3.tar.gz: rivendell-2.15.3/utils/rdgpimon/rdgpimon_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>Database Error</source>
        <translation>Datenbankfehler</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <comment>Unable to connect to mySQL Server!</comment>
        <translation>Kann keine Verbindung zum mySQL-Server herstellen</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Kann keine Verbindung herstellen</translation>
    </message>
    <message>
        <source>Unable to connect to mySQL Server!</source>
        <translation>Kann keine Verbindung zum mySQL-Server herstellen!</translation>
    </message>
    <message>
        <source>Matrix:</source>
        <translation>Matrix:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">S&amp;chließen</translation>
    </message>
    <message>
        <source>RDGpiMon - User:</source>
        <translation type="obsolete">RDGpiMon-Benutzer:</translation>
    </message>
    <message>
        <source>Show:</source>
        <translation>Zeigen:</translation>
    </message>
    <message>
        <source>GPI (Inputs)</source>
        <translation>GPI (Eingänge)</translation>
    </message>
    <message>
        <source>GPO (Outputs)</source>
        <translation>GPO (Ausgänge)</translation>
    </message>
    <message>
        <source>Green = ON Cart</source>
        <translation>Grün = ON Cart</translation>
    </message>
    <message>
        <source>Red = OFF Cart</source>
        <translation>Rot = OFF Cart</translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Both</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Events Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ON </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OFF</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
